@@ -1,8 +1,9 @@
 import Test.Framework       (defaultMain)
-import qualified Tests.SpecFunctions
 import qualified Tests.Chebyshev
-import qualified Tests.Sum
 import qualified Tests.Comparison
+import qualified Tests.RootFinding
+import qualified Tests.SpecFunctions
+import qualified Tests.Sum
 
 main :: IO ()
 main = defaultMain [ Tests.SpecFunctions.tests
@@ -10,4 +11,5 @@ main = defaultMain [ Tests.SpecFunctions.tests
                    -- , Tests.Chebyshev.tests
                    , Tests.Sum.tests
                    , Tests.Comparison.tests
+                   , Tests.RootFinding.tests
                    ]
